VirtualLocation class

Inheritance

Constructors

VirtualLocation({String? externalLink})

Properties

displayText String
no setteroverride
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isOther bool
no setter
label String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited