AdvancedAddressSearchView class

Inheritance

Constructors

AdvancedAddressSearchView({Key? key, required String googleApiKey, required void onSelected(Address?, AddressSuggestion?), required void onDelete(AddressSuggestion?), TextEditingController? textEditingController, AddressSuggestion? initialAddressSuggestion})
An advanced address search view that allows users to select an address from a list of suggestions. The googleApiKey is required to use the Google Places API. The initialAddressSuggestion is the initial address suggestion to display. The onSelected callback is called when an address is selected. The textEditingController can be used to control the text field. The onDelete callback is called when the delete button is pressed.
const

Properties

googleApiKey String
final
hashCode int
The hash code for this object.
no setterinherited
initialAddressSuggestion AddressSuggestion?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDelete → void Function(AddressSuggestion?)
final
onSelected → void Function(Address?, AddressSuggestion?)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textEditingController TextEditingController?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AdvancedAddressSearchView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited