AdvancedAddressSearchView constructor

const AdvancedAddressSearchView({
  1. Key? key,
  2. required String googleApiKey,
  3. required void onSelected(
    1. Address?,
    2. AddressSuggestion?
    ),
  4. required void onDelete(
    1. AddressSuggestion?
    ),
  5. TextEditingController? textEditingController,
  6. AddressSuggestion? initialAddressSuggestion,
})

An advanced address search view that allows users to select an address from a list of suggestions. The googleApiKey is required to use the Google Places API. The initialAddressSuggestion is the initial address suggestion to display. The onSelected callback is called when an address is selected. The textEditingController can be used to control the text field. The onDelete callback is called when the delete button is pressed.

Implementation

const AdvancedAddressSearchView({
  super.key,
  required this.googleApiKey,
  required this.onSelected,
  required this.onDelete,
  this.textEditingController,
  this.initialAddressSuggestion,
});