LocationSearchField class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- LocationSearchField
Constructors
-
LocationSearchField({Key? key, required String googleApiKey, required ValueChanged<
Location?> onSelected, InputDecoration? inputDecoration, String hintText = "Search address", String labelText = "Location: in person or virtual"}) -
const
Properties
- googleApiKey → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String
-
A location search field that allows users to select a physical address
or a virtual location.
The googleApiKey is required to use the Google Places API.
The onSelected callback is called when a location is selected.
The inputDecoration can be used to customize the appearance of the text field.
The hintText is the hint text for the text field.
The labelText is the label for the text field.
final
- inputDecoration → InputDecoration?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelText → String
-
final
-
onSelected
→ ValueChanged<
Location?> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< LocationSearchField> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited