hintText property
A location search field that allows users to select a physical address or a virtual location. The googleApiKey is required to use the Google Places API. The onSelected callback is called when a location is selected. The inputDecoration can be used to customize the appearance of the text field. The hintText is the hint text for the text field. The labelText is the label for the text field.
Implementation
final String hintText;