SuggestionListItem class

Inheritance

Constructors

SuggestionListItem({Key? key, required AddressSuggestion suggestion, required ValueChanged<AddressSuggestion?> onSelected, Function? onDelete, IconData icon = Icons.location_on})
A list item that displays an address suggestion. The suggestion is the address suggestion to display. The onSelected callback is called when the suggestion is selected. The onDelete callback is called when the delete button is pressed. The icon is the icon to display in the leading position.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDelete Function?
final
onSelected ValueChanged<AddressSuggestion?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggestion AddressSuggestion
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited