SuggestionListItem constructor

const SuggestionListItem({
  1. Key? key,
  2. required AddressSuggestion suggestion,
  3. required ValueChanged<AddressSuggestion?> onSelected,
  4. Function? onDelete,
  5. IconData icon = Icons.location_on,
})

A list item that displays an address suggestion. The suggestion is the address suggestion to display. The onSelected callback is called when the suggestion is selected. The onDelete callback is called when the delete button is pressed. The icon is the icon to display in the leading position.

Implementation

const SuggestionListItem({
  super.key,
  required this.suggestion,
  required this.onSelected,
  this.onDelete,
  this.icon = Icons.location_on,
});