Address class
Constructors
- Address({required String formattedAddress, required String city, int? streetNumber, String? street, required String state, required String postalCode, required String country, required double longitude, required double latitude, String? mainText, String? secondaryText})
-
Address.fromJson(Map<
String, dynamic> json) -
factory
Properties
- city → String
-
final
- country → String
-
final
- displayText → String
-
no setteroverride
- formattedAddress → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
no setteroverride
- latitude → double
-
final
- longitude → double
-
final
- mainText ↔ String?
-
getter/setter pair
- postalCode → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryText ↔ String?
-
getter/setter pair
- state → String
-
final
- street → String?
-
final
- streetNumber → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited