SuggestionListItem constructor
const
SuggestionListItem({
- Key? key,
- required AddressSuggestion suggestion,
- required ValueChanged<
AddressSuggestion?> onSelected, - Function? onDelete,
- IconData icon = Icons.location_on,
A list item that displays an address suggestion.
The suggestion is the address suggestion to display.
The onSelected callback is called when the suggestion is selected.
The onDelete callback is called when the delete button is pressed.
The icon is the icon to display in the leading position.
Implementation
const SuggestionListItem({
super.key,
required this.suggestion,
required this.onSelected,
this.onDelete,
this.icon = Icons.location_on,
});